Shared live-progress counters for the quantification drivers.
Structs
- Progress
Counters - Lock-free counters a quant driver updates as it runs, so a UI (e.g. a CLI
progress bar) can poll mapping progress while quantification is in flight.
Shared by both the reads-mode (
salmon-quant) and alignment-mode (salmon-align) drivers.